@@ -200,8 +200,8 @@ setSDMXServiceProviders <- function(){ # nocov start
     agencyId = "INSEE", name = "Institut national de la statistique et des \u00e9tudes \u00e9conomiques",
     scale = "national", country = "FRA",
     builder = SDMXREST21RequestBuilder(
-      regUrl = "http://www.bdm.insee.fr/series/sdmx",
-      repoUrl = "http://www.bdm.insee.fr/series/sdmx", 
+      regUrl = "https://bdm.insee.fr/series/sdmx",
+      repoUrl = "https://bdm.insee.fr/series/sdmx", 
       compliant = TRUE)
   )
   
@@ -272,6 +272,28 @@ setSDMXServiceProviders <- function(){ # nocov start
     )
   )
   
+  #LSD - Lithuanian Department of Statistics (Statistics Lithuania)
+  LSD <- SDMXServiceProvider(
+    agencyId = "LSD", "Statistics Lithuania",
+    scale = "national", country = "LTU",
+    builder = SDMXREST21RequestBuilder(
+      regUrl = "https://osp-rs.stat.gov.lt/rest_xml",
+      repoUrl = "https://osp-rs.stat.gov.lt/rest_xml",
+      compliant = TRUE, skipProviderId = TRUE
+    )
+  )
+  
+  #STAT_EE - Statistics Estonia database {Estonia}
+  STAT_EE <- SDMXServiceProvider(
+    agencyId = "STAT_EE", name = "Statistics Estonia database",
+    scale = "national", country = "EST",
+    builder = SDMXDotStatRequestBuilder(
+      regUrl = "http://andmebaas.stat.ee/restsdmx/sdmx.ashx",
+      repoUrl = "http://andmebaas.stat.ee/restsdmx/sdmx.ashx",
+      unsupportedResources = list("dataflow")
+    )
+  )
+  
   #other data providers
   #--------------------
   
@@ -377,7 +399,7 @@ setSDMXServiceProviders <- function(){ # nocov start
     #international
     ECB, ESTAT, IMF, OECD, UNSD, FAO, ILO, UIS, UIS2, WBG_WITS,
     #national
-    ABS, NBB, INSEE, INEGI, ISTAT, NOMIS,
+    ABS, NBB, INSEE, INEGI, ISTAT, NOMIS, LSD, STAT_EE,
     #others
     KNOEMA, WIDUKIND
   )
